@@ -158,7 +158,7 @@ void SyntaxHighlighter::highlightBlock(const QString &text)
         }
     }
 
-    foreach (const HighlightingRule &rule, highlightingRules) {
+    for (const HighlightingRule &rule : qAsConst(highlightingRules)) {
         QRegExp expression(rule.pattern);
         int index = expression.indexIn(text);
         while (index >= 0) {
